==> java-micro-1.1-20180823.065328-6-sources.jar: com/xunyi/micro/grpc/discovery/DiscoveryChannelFactory.java <==
package com.xunyi.micro.grpc.discovery;


import com.google.common.collect.Lists;
import com.xunyi.micro.grpc.GRPCChannelFactory;
import com.xunyi.micro.grpc.GRPCChannelProperties;
import com.xunyi.micro.grpc.GRPCChannelsProperties;
import io.grpc.Channel;
import io.grpc.ClientInterceptor;
import io.grpc.ClientInterceptors;
import io.grpc.LoadBalancer;
import io.grpc.netty.NettyChannelBuilder;
import org.springframework.cloud.client.discovery.DiscoveryClient;

import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

public class DiscoveryChannelFactory implements GRPCChannelFactory {

    private final GRPCChannelsProperties properties;

    private final DiscoveryClient client;

    private final LoadBalancer.Factory loadBalancerFactory;

    private final List<ClientInterceptor> globalInterceptor;

    public DiscoveryChannelFactory(GRPCChannelsProperties properties,
                                   DiscoveryClient client,
                                   LoadBalancer.Factory loadBalancerFactory,
                                   ClientInterceptor... globalInterceptor) {
        this.properties = properties;
        this.client = client;
        this.loadBalancerFactory = loadBalancerFactory;
        this.globalInterceptor = Lists.newArrayList(globalInterceptor);
    }

    @Override
    public Channel createChannel(String name) {
        return this.createChannel(name, null);
    }

    @Override
    public Channel createChannel(String name, List<ClientInterceptor> interceptors) {
        GRPCChannelProperties channelProperties = properties.getChannel(name);

        NettyChannelBuilder builder = NettyChannelBuilder.forTarget(name)
                .loadBalancerFactory(loadBalancerFactory)
                .nameResolverFactory(new DiscoveryNameResolverProvider(client))
                .negotiationType(channelProperties.getNegotiationType());

        if (channelProperties.isEnableKeepAlive()) {
            builder.keepAliveWithoutCalls(channelProperties.isKeepAliveWithoutCalls())
                    .keepAliveTime(channelProperties.getKeepAliveTime(), TimeUnit.SECONDS)
                    .keepAliveTimeout(channelProperties.getKeepAliveTimeout(), TimeUnit.SECONDS);
        }
        if(channelProperties.getMaxInboundMessageSize() > 0) {
            builder.maxInboundMessageSize(channelProperties.getMaxInboundMessageSize());
        }
        Channel channel = builder.build();
        List<ClientInterceptor> interceptorList = Lists.newArrayList(globalInterceptor);
        if (Objects.nonNull(interceptors)) {
            interceptorList.addAll(interceptors);
        }
        return ClientInterceptors.intercept(channel, interceptorList);
    }


}

==> java-micro-2.2.2-20200807.100124-51-sources.jar: com/xunyi/micro/grpc/discovery/DiscoveryChannelFactory.java <==
package com.xunyi.micro.grpc.discovery;


import com.google.common.collect.Lists;
import com.xunyi.micro.grpc.GRPCChannelFactory;
import com.xunyi.micro.grpc.GRPCChannelProperties;
import com.xunyi.micro.grpc.GRPCChannelsProperties;
import io.grpc.Channel;
import io.grpc.ClientInterceptor;
import io.grpc.ClientInterceptors;
import io.grpc.LoadBalancer;
import io.grpc.netty.NettyChannelBuilder;
import org.springframework.cloud.client.discovery.DiscoveryClient;

import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

public class DiscoveryChannelFactory implements GRPCChannelFactory {

    private final GRPCChannelsProperties properties;

    private final DiscoveryClient client;

//    private final LoadBalancer.Factory loadBalancerFactory;

    private final List<ClientInterceptor> globalInterceptor;

    public DiscoveryChannelFactory(GRPCChannelsProperties properties,
                                   DiscoveryClient client,
//                                   LoadBalancer.Factory loadBalancerFactory,
                                   List<ClientInterceptor> globalInterceptor) {
        this.properties = properties;
        this.client = client;
//        this.loadBalancerFactory = loadBalancerFactory;
        this.globalInterceptor = Lists.newArrayList(globalInterceptor);
    }

    @Override
    public Channel createChannel(String name) {
        return this.createChannel(name, null);
    }

    @Override
    public Channel createChannel(String name, List<ClientInterceptor> interceptors) {
        GRPCChannelProperties channelProperties = properties.getChannel(name);

        NettyChannelBuilder builder = NettyChannelBuilder.forTarget(name)
//                .loadBalancerFactory(loadBalancerFactory)
                .nameResolverFactory(new DiscoveryNameResolverProvider(client))
                .negotiationType(channelProperties.getNegotiationType());

        if (channelProperties.isEnableKeepAlive()) {
            builder.keepAliveWithoutCalls(channelProperties.isKeepAliveWithoutCalls())
                    .keepAliveTime(channelProperties.getKeepAliveTime(), TimeUnit.SECONDS)
                    .keepAliveTimeout(channelProperties.getKeepAliveTimeout(), TimeUnit.SECONDS);
        }
        if(channelProperties.getMaxInboundMessageSize() > 0) {
            builder.maxInboundMessageSize(channelProperties.getMaxInboundMessageSize());
        }
        Channel channel = builder.build();
        List<ClientInterceptor> interceptorList = Lists.newArrayList(globalInterceptor);
        if (Objects.nonNull(interceptors)) {
            interceptorList.addAll(interceptors);
        }
        return ClientInterceptors.intercept(channel, interceptorList);
    }


}
